-------------------------------------------------------------------------------
-- |> weizPVP
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- |> UPVALUE GLOBALS
-------------------------------------------------------------------------------
local weizPVP = weizPVP
local wipe = wipe
local C_UI_Reload = C_UI.Reload
local LibStub = LibStub

-------------------------------------------------------------------------------
-- |> INITIALIZE
-------------------------------------------------------------------------------
--> The start of processing; entry point.
-------------------------------------------------------------------------------
function weizPVP:OnInitialize()
	--> LOAD ACE3 DB
	weizPVP.db = LibStub("AceDB-3.0"):New("weizPVPOptions")
	if not weizPVP.db.profile.Options then
		weizPVP.db.profile.Options = {}
	end
	if not weizPVP.db.global.PlayerDB then
		weizPVP.db.global.PlayerDB = {}
	end

	--> Load Database and apply static options
	weizPVP:LoadDB()
	weizPVP:ApplyStaticOptions()

	--> Save Options
	weizPVP:ApplySavedOptions()
end

-------------------------------------------------------------------------------
-- |> ON ENABLE
-------------------------------------------------------------------------------
function weizPVP:OnEnable()
	weizPVP.ManageBarsDisplayed()
	weizPVP.HeaderFrame:Show()
	weizPVP.CoreFrame:Show()
	weizPVP.FooterFrame:Show()

	--> Timers
	weizPVP:ScheduleRepeatingTimer("OneSecondTimer", 1)
	--> 1 second timer used for periodic updating.
	weizPVP:ScheduleRepeatingTimer("SaveAddonData", 10)
	--> Saves data every 10 seconds

	--> Enable Events
	weizPVP.EnableEvents()

	weizPVP.Addon.Enabled = true
end

-------------------------------------------------------------------------------
-- |> ON DISABLE
-------------------------------------------------------------------------------
function weizPVP:OnDisable()
	--> Hide frames
	weizPVP.HeaderFrame:Hide()
	weizPVP.CoreFrame:Hide()
	weizPVP.FooterFrame:Hide()

	weizPVP:CancelAllTimers()
	--> Cancel Timers

	--> Clear current player data
	weizPVP:ClearListData()

	--> Enable Events
	weizPVP.EnableEvents()

	weizPVP.Addon.Enabled = false
end

-------------------------------------------------------------------------------
-- |> LOAD SAVED VARIABLE
------------------------------------------------------------------------------
--> Save Addon Data
-------------------------------------------------------------------------------
function weizPVP:SaveAddonData()
	weizPVP.db.global.PlayerDB = weizPVP.PlayerDB
	weizPVP.db.profile.Options = weizPVP.Options
end

--> Reset All
-------------------------------------------------------------------------------
function weizPVP:ResetAll()
	if weizPVP.db.profile then
		wipe(weizPVP.db.profile)
	end
	if weizPVP.db.profile then
		wipe(weizPVP.db.profile)
	end
	if weizPVP.db.global then
		wipe(weizPVP.db.global)
	end
	if weizPVP.PlayerDB then
		wipe(weizPVP.PlayerDB)
	end
	if weizPVP.Options then
		wipe(weizPVP.Options)
	end
	wipe(weizPVP.db)

	C_UI_Reload()
end

--> Reset Options
-------------------------------------------------------------------------------
function weizPVP:ResetOptions()
	if weizPVP.Options then
		wipe(weizPVP.Options)
	end
	C_UI_Reload()
end
